

export interface SessionNodeInfo {
	name: string
	type: number
	shape: number[]
}

export type SessionNodeType = "float32" | "float64" | "float" | "double" | "int32" | "uint32" | "int16" | "uint16" | "int8" | "uint8" | "int64" | "uint64"

export type SessionNodeData = Float32Array | Float64Array | Int32Array | Uint32Array | Int16Array | Uint16Array | Int8Array | Uint8Array | BigInt64Array | BigUint64Array

export interface SessionRunInputOption {
	type?: SessionNodeType
	data: SessionNodeData
	shape?: number[]
}

export abstract class CommonSession {
	public abstract run(inputs: Record<string, SessionNodeData | SessionRunInputOption>): Promise<Record<string, Float32Array>>

	public abstract get inputs(): Record<string, SessionNodeInfo>;
	public abstract get outputs(): Record<string, SessionNodeInfo>;
}

export function isTypedArray(val: any): val is SessionNodeData {
	return val?.buffer instanceof ArrayBuffer;
}
